@@ -73,7 +73,7 @@ step_invlogit_new <-
 #' @export
 prep.step_invlogit <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   step_invlogit_new(
     terms = x$terms,
