@@ -124,7 +124,7 @@ step_spline_nonnegative_new <-
 
 prep.step_spline_nonnegative <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names], quant = TRUE)
+  check_type(training[, col_names], types = c("double", "integer"))
 
   res <-
     purrr::map2(
