@@ -1,21 +1,40 @@
 library(testthat)
 library(recipes)
 
-library(modeldata)
-data(covers)
-rec <- recipe(~ description, covers) %>%
+skip_if_not_installed("modeldata")
+data(covers, package = "modeldata")
+rec <- recipe(~description, covers) %>%
   step_regex(description, pattern = "(rock|stony)", result = "rocks") %>%
   step_regex(description, pattern = "(rock|stony)", result = "more_rocks")
 
-test_that('default options', {
+test_that("default options", {
   rec1 <- rec %>% step_bin2factor(rocks)
   rec1 <- prep(rec1, training = covers)
   res1 <- bake(rec1, new_data = covers)
   expect_true(all(diag(table(res1$rocks, res1$more_rocks)) == 0))
 })
 
+test_that("works with logicals", {
+  mtcars$vs <- as.logical(mtcars$vs)
+  mtcars$am <- as.logical(mtcars$am)
 
-test_that('nondefault options', {
+  res <- recipe(~., data = mtcars) %>%
+    step_bin2factor(all_logical_predictors()) %>%
+    prep() %>%
+    bake(new_data = NULL)
+
+  expect_identical(
+    factor(mtcars$vs, levels = c(TRUE, FALSE), labels = c("yes", "no")),
+    res$vs
+  )
+  expect_identical(
+    factor(mtcars$am, levels = c(TRUE, FALSE), labels = c("yes", "no")),
+    res$am
+  )
+})
+
+
+test_that("nondefault options", {
   rec2 <- rec %>% step_bin2factor(rocks, levels = letters[2:1])
   rec2 <- prep(rec2, training = covers)
   res2 <- bake(rec2, new_data = covers)
@@ -23,22 +42,28 @@ test_that('nondefault options', {
 })
 
 
-test_that('bad options', {
+test_that("bad options", {
   rec3 <- rec %>% step_bin2factor(description)
-  expect_error(prep(rec3, training = covers))
-  expect_error(rec %>% step_bin2factor(rocks, levels = letters[1:5]))
-  expect_error(rec %>% step_bin2factor(rocks, levels = 1:2))
+  expect_snapshot(error = TRUE,
+    prep(rec3, training = covers)
+  )
+  expect_snapshot(error = TRUE,
+    rec %>% step_bin2factor(rocks, levels = letters[1:5])
+  )
+  expect_snapshot(error = TRUE,
+    rec %>% step_bin2factor(rocks, levels = 1:2)
+  )
 })
 
 
-test_that('printing', {
+test_that("printing", {
   rec2 <- rec %>% step_bin2factor(rocks, levels = letters[2:1])
-  expect_output(print(rec2))
-  expect_output(prep(rec2, training = covers, verbose = TRUE))
+  expect_snapshot(print(rec2))
+  expect_snapshot(prep(rec2))
 })
 
 
-test_that('choose reference level', {
+test_that("choose reference level", {
   rec4 <- rec %>% step_bin2factor(rocks, ref_first = FALSE)
   rec4 <- prep(rec4, training = covers)
   res4 <- bake(rec4, new_data = covers)
@@ -83,3 +108,16 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("bake method errors when needed non-standard role columns are missing", {
+  mtcars_bin <- mtcars %>% mutate(bin = c(1, rep(0, nrow(mtcars) - 1)))
+
+  rec <- recipe(mpg ~ ., mtcars_bin)
+  rec <- step_bin2factor(rec, "bin") %>%
+    update_role(bin, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  rec <- prep(rec, mtcars_bin)
+
+  expect_error(bake(rec, mtcars), class = "new_data_missing_column")
+})
