@@ -53,10 +53,44 @@ test_that("Date class", {
   )
 })
 
+test_that("Date class", {
+  holiday_rec <- recipe(~day, test_data) %>%
+    step_holiday(all_predictors(),
+                 holidays = exp_dates$holiday,
+                 keep_original_cols = FALSE)
+
+  holiday_rec <- prep(holiday_rec, training = test_data)
+  holiday_ind <- bake(holiday_rec, test_data, all_predictors())
+
+  expect_true(all(vapply(holiday_ind, is.integer, logical(1))))
+})
+
+test_that("works with no missing values - Date class", {
+  test_data <- na.omit(test_data)
+
+  holiday_rec <- recipe(~day, test_data) %>%
+    step_holiday(all_predictors(), holidays = exp_dates$holiday)
+
+  holiday_rec <- prep(holiday_rec, training = test_data)
+  holiday_ind <- bake(holiday_rec, test_data)
+
+  expect_equal(
+    holiday_ind$day[is_equal_1(holiday_ind$day_USMemorialDay)],
+    exp_dates$date[exp_dates$holiday == "USMemorialDay"]
+  )
+  expect_equal(
+    holiday_ind$day[is_equal_1(holiday_ind$day_ChristmasDay)],
+    exp_dates$date[exp_dates$holiday == "ChristmasDay"]
+  )
+  expect_equal(
+    holiday_ind$day[is_equal_1(holiday_ind$day_Easter)],
+    exp_dates$date[exp_dates$holiday == "Easter"]
+  )
+})
 
 test_that("POSIXct class", {
-  test_data$day <- as.POSIXct(test_data$day)
-  exp_dates$date <- as.POSIXct(exp_dates$date)
+  test_data$day <- lubridate::as_datetime(test_data$day, tz = "UTC")
+  exp_dates$date <- lubridate::as_datetime(exp_dates$date, tz = "UTC")
 
   holiday_rec <- recipe(~day, test_data) %>%
     step_holiday(all_predictors(), holidays = exp_dates$holiday)
@@ -78,7 +112,7 @@ test_that("POSIXct class", {
   )
   expect_equal(
     holiday_ind$day[is.na(test_data$day)],
-    as.POSIXct(NA, tz = NULL)
+    as.POSIXct(NA, tz = "UTC")
   )
   expect_equal(
     holiday_ind$day_ChristmasDay[is.na(test_data$day)],
@@ -94,6 +128,47 @@ test_that("POSIXct class", {
   )
 })
 
+test_that("Date class", {
+  test_data$day <- as.POSIXct(test_data$day)
+  exp_dates$date <- as.POSIXct(exp_dates$date)
+
+  holiday_rec <- recipe(~day, test_data) %>%
+    step_holiday(all_predictors(),
+                 holidays = exp_dates$holiday,
+                 keep_original_cols = FALSE)
+
+  holiday_rec <- prep(holiday_rec, training = test_data)
+  holiday_ind <- bake(holiday_rec, test_data, all_predictors())
+
+  expect_true(all(vapply(holiday_ind, is.integer, logical(1))))
+})
+
+
+test_that("works with no missing values - POSIXct class", {
+  test_data <- na.omit(test_data)
+
+  test_data$day <- as.POSIXct(test_data$day)
+  exp_dates$date <- as.POSIXct(exp_dates$date)
+
+  holiday_rec <- recipe(~day, test_data) %>%
+    step_holiday(all_predictors(), holidays = exp_dates$holiday)
+
+  holiday_rec <- prep(holiday_rec, training = test_data)
+  holiday_ind <- bake(holiday_rec, test_data)
+
+  expect_equal(
+    holiday_ind$day[is_equal_1(holiday_ind$day_USMemorialDay)],
+    exp_dates$date[exp_dates$holiday == "USMemorialDay"]
+  )
+  expect_equal(
+    holiday_ind$day[is_equal_1(holiday_ind$day_ChristmasDay)],
+    exp_dates$date[exp_dates$holiday == "ChristmasDay"]
+  )
+  expect_equal(
+    holiday_ind$day[is_equal_1(holiday_ind$day_Easter)],
+    exp_dates$date[exp_dates$holiday == "Easter"]
+  )
+})
 
 test_that("printing", {
   holiday_rec <- recipe(~day, test_data) %>%
